@@ -22,7 +22,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
     "Ext.dirac.utils.DiracMultiSelect",
     "Ext.util.*",
     "Ext.toolbar.Toolbar",
-    "Ext.data.Record"
+    "Ext.data.Record",
   ],
   timeout: 7200000, // 2 hours
   title: "",
@@ -30,25 +30,25 @@ Ext.define("Ext.dirac.utils.PlotView", {
   reportsDesc: {},
   reportTypes: [
     ["Accounting", "Accounting"],
-    ["Monitoring", "Monitoring"]
+    ["Monitoring", "Monitoring"],
   ],
   handlers: {},
   actualReport: null,
-  loadState: function(oData) {
+  loadState: function (oData) {
     var me = this;
     me.rightPanel.loadState(oData);
   },
-  getStateData: function() {
+  getStateData: function () {
     var me = this;
     var oReturn = me.rightPanel.getStateData();
 
     return oReturn;
   },
 
-  initComponent: function() {
+  initComponent: function () {
     var me = this;
 
-    me.loadFile(["static/core/js/utils/css/PlotView.css"], function() {}, me);
+    me.loadFile(["static/core/js/utils/css/PlotView.css"], function () {}, me);
 
     me.launcher.title = me.title;
     me.launcher.maximized = false;
@@ -66,14 +66,14 @@ Ext.define("Ext.dirac.utils.PlotView", {
       bodyBorder: false,
       defaults: {
         collapsible: true,
-        split: true
-      }
+        split: true,
+      },
     });
 
     me.callParent(arguments);
   },
 
-  buildUI: function() {
+  buildUI: function () {
     var me = this;
     me.callParent();
 
@@ -87,7 +87,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       maxWidth: 550,
       bodyPadding: 5,
       layout: "anchor",
-      scrollable: true
+      scrollable: true,
     });
 
     me.rightPanel = Ext.create("Ext.dirac.utils.Presenter", {
@@ -99,7 +99,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       parent: me,
       reportType: "",
       scope: me,
-      collapsible: false
+      collapsible: false,
     });
 
     me.cmbReportType = Ext.create("Ext.form.field.ComboBox", {
@@ -111,10 +111,10 @@ Ext.define("Ext.dirac.utils.PlotView", {
       anchor: "100%",
       store: new Ext.data.ArrayStore({
         fields: ["value", "text"],
-        data: me.reportTypes
+        data: me.reportTypes,
       }),
       listeners: {
-        change: function(field, newValue, oldValue, eOpts) {
+        change: function (field, newValue, oldValue, eOpts) {
           if (newValue == null) return;
 
           me.leftPanel.body.mask("Wait ...");
@@ -123,8 +123,8 @@ Ext.define("Ext.dirac.utils.PlotView", {
           me.applyReportType(newValue);
           me.leftPanel.body.unmask();
           me.cmbDomain.resumeEvent("change");
-        }
-      }
+        },
+      },
     });
 
     me.cmbDomain = Ext.create("Ext.form.field.ComboBox", {
@@ -136,10 +136,10 @@ Ext.define("Ext.dirac.utils.PlotView", {
       anchor: "100%",
       store: new Ext.data.ArrayStore({
         fields: ["value", "text"],
-        data: []
+        data: [],
       }),
       listeners: {
-        change: function(field, newValue, oldValue, eOpts) {
+        change: function (field, newValue, oldValue, eOpts) {
           if (newValue == null) return;
 
           me.leftPanel.body.mask("Wait ...");
@@ -148,20 +148,20 @@ Ext.define("Ext.dirac.utils.PlotView", {
             timeout: me.timeout,
             method: "POST",
             params: {
-              type: newValue
+              type: newValue,
             },
             scope: me,
-            success: function(response) {
+            success: function (response) {
               var oResult = Ext.JSON.decode(response.responseText);
               if (oResult["success"] == "true") {
                 me.applyDataToSelection(oResult, newValue, me.actualReport);
                 me.cmbReportType.resumeEvent("change");
               } else GLOBAL.APP.CF.alert(oResult["error"], "error");
               me.leftPanel.body.unmask();
-            }
+            },
           });
-        }
-      }
+        },
+      },
     });
 
     me.cmbPlotGenerate = Ext.create("Ext.form.field.ComboBox", {
@@ -170,7 +170,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       labelAlign: "top",
       displayField: "text",
       valueField: "value",
-      anchor: "100%"
+      anchor: "100%",
     });
 
     me.cmbGroupBy = Ext.create("Ext.form.field.ComboBox", {
@@ -179,18 +179,18 @@ Ext.define("Ext.dirac.utils.PlotView", {
       labelAlign: "top",
       displayField: "text",
       valueField: "value",
-      anchor: "100%"
+      anchor: "100%",
     });
 
     me.fsetTimeSpan = Ext.create("Ext.form.FieldSet", {
       title: "Time Span",
       collapsible: true,
-      layout: "anchor"
+      layout: "anchor",
     });
 
     me.cmbTimeSpanStore = new Ext.data.ArrayStore({
       fields: ["value", "text"],
-      data: me.dataSelectors["Accounting"]["dataSelector"]
+      data: me.dataSelectors["Accounting"]["dataSelector"],
     });
 
     me.cmbTimeSpan = Ext.create("Ext.form.field.ComboBox", {
@@ -201,7 +201,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       value: me.dataSelectors["Accounting"]["dataSelector"][0][0],
       store: me.cmbTimeSpanStore,
       listeners: {
-        change: function(field, newValue, oldValue, eOpts) {
+        change: function (field, newValue, oldValue, eOpts) {
           me.calendarFrom.hide();
           me.calendarTo.hide();
           me.cmbQuarter.hide();
@@ -216,8 +216,8 @@ Ext.define("Ext.dirac.utils.PlotView", {
               me.cmbQuarter.show();
               break;
           }
-        }
-      }
+        },
+      },
     });
 
     me.calendarFrom = new Ext.create("Ext.form.field.Date", {
@@ -225,7 +225,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       format: "Y-m-d",
       fieldLabel: "Initial Date",
       labelAlign: "top",
-      hidden: true
+      hidden: true,
     });
 
     me.calendarTo = new Ext.create("Ext.form.field.Date", {
@@ -233,7 +233,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       format: "Y-m-d",
       fieldLabel: "End Date",
       labelAlign: "top",
-      hidden: true
+      hidden: true,
     });
 
     me.cmbQuarter = Ext.create("Ext.dirac.utils.DiracBoxSelect", {
@@ -241,7 +241,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       displayField: "text",
       valueField: "value",
       anchor: "100%",
-      hidden: true
+      hidden: true,
     });
 
     me.fsetTimeSpan.add([me.cmbTimeSpan, me.calendarFrom, me.calendarTo, me.cmbQuarter]);
@@ -249,27 +249,27 @@ Ext.define("Ext.dirac.utils.PlotView", {
     me.fsetSpecialConditions = Ext.create("Ext.form.FieldSet", {
       title: "Selection Conditions",
       collapsible: true,
-      layout: "anchor"
+      layout: "anchor",
     });
 
     me.fsetAdvanced = Ext.create("Ext.form.FieldSet", {
       title: "Advanced Options",
       collapsible: true,
-      layout: "anchor"
+      layout: "anchor",
     });
 
     me.advancedPlotTitle = Ext.create("Ext.form.field.Text", {
       fieldLabel: "Plot Title",
       labelAlign: "top",
-      anchor: "100%"
+      anchor: "100%",
     });
 
     me.advancedPin = Ext.create("Ext.form.field.Checkbox", {
-      boxLabel: "Pin Dates"
+      boxLabel: "Pin Dates",
     });
 
     me.advancedNotScaleUnits = Ext.create("Ext.form.field.Checkbox", {
-      boxLabel: "Do not scale units"
+      boxLabel: "Do not scale units",
     });
 
     me.fsetAdvanced.add([me.advancedPlotTitle, me.advancedPin, me.advancedNotScaleUnits]);
@@ -281,10 +281,10 @@ Ext.define("Ext.dirac.utils.PlotView", {
       text: "New",
       margin: 3,
       iconCls: "accp-submit-icon",
-      handler: function() {
+      handler: function () {
         me.__generatePlot(null, null, true);
       },
-      scope: me
+      scope: me,
     });
 
     me.btnReset = new Ext.Button({
@@ -292,10 +292,10 @@ Ext.define("Ext.dirac.utils.PlotView", {
       text: "Reset",
       margin: 3,
       iconCls: "accp-reset-icon",
-      handler: function() {
+      handler: function () {
         me.__resetSelectionWindow();
       },
-      scope: me
+      scope: me,
     });
 
     me.btnRefresh = new Ext.Button({
@@ -303,31 +303,31 @@ Ext.define("Ext.dirac.utils.PlotView", {
       text: "Refresh",
       margin: 3,
       iconCls: "accp-refresh-icon",
-      handler: function() {
+      handler: function () {
         me.leftPanel.body.mask("Wait ...");
         Ext.Ajax.request({
           url: GLOBAL.BASE_URL + me.handlers[me.actualReport] + "/getSelectionData",
           timeout: me.timeout,
           method: "POST",
           params: {
-            type: me.cmbDomain.getValue()
+            type: me.cmbDomain.getValue(),
           },
           scope: me,
-          success: function(response) {
+          success: function (response) {
             var oResult = Ext.JSON.decode(response.responseText);
 
             if (oResult["success"] == "true") me.applySpecialConditions(oResult);
             else alert(oResult["error"]);
             me.leftPanel.body.unmask();
           },
-          failure: function(response, opt) {
+          failure: function (response, opt) {
             GLOBAL.APP.CF.showAjaxErrorMessage(response);
             me.rightPanel.body.unmask();
             me.leftPanel.body.unmask();
-          }
+          },
         });
       },
-      scope: me
+      scope: me,
     });
 
     /*
@@ -339,7 +339,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       text: "Apply",
       margin: 3,
       iconCls: "dirac-icon-upload",
-      handler: function() {
+      handler: function () {
         image = me.rightPanel.getLastClickedImage();
         if (image != null) {
           me.__generatePlot(image, null);
@@ -347,7 +347,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
           Ext.dirac.system_info.msg("Notification", "Please select an image what you want to change!");
         }
       },
-      scope: me
+      scope: me,
     });
 
     me.btnApplyAll = new Ext.Button({
@@ -355,25 +355,25 @@ Ext.define("Ext.dirac.utils.PlotView", {
       text: "ApplyAll",
       margin: 3,
       iconCls: "dirac-icon-upload",
-      handler: function() {
+      handler: function () {
         var me = this;
         var oParamsData = me.__getSelectionParametars("show_plot");
         me.rightPanel.applyTimeSpan(oParamsData);
       },
-      scope: me
+      scope: me,
     });
 
     var oPanelButtons = new Ext.create("Ext.toolbar.Toolbar", {
       items: [me.btnPlot, me.btnRefreshPlot, me.btnReset, me.btnRefresh, me.btnApplyAll],
       layout: "column",
       columnWidth: 3,
-      dock: "bottom"
+      dock: "bottom",
     });
 
     me.leftPanel.addDocked(oPanelButtons);
     me.add([me.leftPanel, me.rightPanel]);
   },
-  __generatePlot: function(image, oLoadState, selectAddedPlot) {
+  __generatePlot: function (image, oLoadState, selectAddedPlot) {
     var me = this;
     var oParams = null;
     if (oLoadState == null) {
@@ -414,7 +414,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
         timeout: me.timeout,
         params: oParams,
         scope: me,
-        success: function(response) {
+        success: function (response) {
           var me = this;
 
           me.leftPanel.body.unmask();
@@ -428,7 +428,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
             GLOBAL.APP.CF.alert(response["errors"], "error");
           }
         },
-        failure: function(response, opt) {
+        failure: function (response, opt) {
           GLOBAL.APP.CF.showAjaxErrorMessage(response);
 
           if (me.rightPanel.body) {
@@ -437,7 +437,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
           if (me.leftPanel.body) {
             me.leftPanel.body.unmask();
           }
-        }
+        },
       });
     } else {
       if (me.rightPanel.body) {
@@ -461,9 +461,9 @@ Ext.define("Ext.dirac.utils.PlotView", {
         leftPanel: me.leftPanel,
         scope: me,
         listeners: {
-          afterrender: function(me) {
+          afterrender: function (me) {
             me.el.on({
-              load: function(evt, ele, opts) {
+              load: function (evt, ele, opts) {
                 me.setLoading(false);
                 if (me.isSetSrc) {
                   if (me.rightPanel.body) {
@@ -482,12 +482,12 @@ Ext.define("Ext.dirac.utils.PlotView", {
                     me.rightPanel.selectImage(me);
                   }
                 }
-              }
+              },
             });
           },
 
           // When new plot added on the wall generate image
-          added: function(container, pos, eOpts) {
+          added: function (container, pos, eOpts) {
             var me = this;
             me.setLoading(true);
             Ext.Ajax.request({
@@ -495,7 +495,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
               timeout: me.timeout,
               params: oParams,
               scope: me,
-              success: function(response) {
+              success: function (response) {
                 var me = this;
 
                 if (me.leftPanel.body) {
@@ -514,7 +514,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
                   GLOBAL.APP.CF.alert(response["errors"], "error");
                 }
               },
-              failure: function(response, opt) {
+              failure: function (response, opt) {
                 GLOBAL.APP.CF.showAjaxErrorMessage(response);
 
                 if (me.rightPanel.body) {
@@ -525,23 +525,23 @@ Ext.define("Ext.dirac.utils.PlotView", {
                 }
 
                 me.setLoading(false);
-              }
+              },
             });
-          }
-        }
+          },
+        },
       });
 
       me.rightPanel.addImage(oImg);
     }
   },
-  __loadSelectionData: function(oParams) {
+  __loadSelectionData: function (oParams) {
     var me = this;
 
     me.plotParams = oParams;
 
     if (!("_typeName" in oParams)) return;
 
-    me.__additionalDataLoad = function() {
+    me.__additionalDataLoad = function () {
       me.cmbGroupBy.setValue(oParams["_grouping"]);
       me.cmbPlotGenerate.setValue(oParams["_plotName"]);
       me.cmbTimeSpan.setValue(oParams["_timeSelector"]);
@@ -593,7 +593,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
         "_endTime",
         "_plotTitle",
         "_pinDates",
-        "_ex_staticUnits"
+        "_ex_staticUnits",
       ];
 
       for (var oParam in oParams) {
@@ -635,7 +635,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       me.cmbDomain.setValue(oParams["_typeName"]);
     }
   },
-  __getSelectionParametars: function(sIntention) {
+  __getSelectionParametars: function (sIntention) {
     var me = this;
 
     var sDomain = me.cmbDomain.getValue();
@@ -643,10 +643,10 @@ Ext.define("Ext.dirac.utils.PlotView", {
     var oParams = {
       _grouping: me.cmbGroupBy.getValue(),
       _plotName: me.cmbPlotGenerate.getValue(),
-      _typeName: sDomain
+      _typeName: sDomain,
     };
 
-    var fixTime = function(st) {
+    var fixTime = function (st) {
       var year = st.getFullYear().toString();
       var month = st.getMonth() + 1;
       month = (month < 10 ? "0" : "") + month;
@@ -725,7 +725,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
 
     return oParams;
   },
-  __fillComboQuarter: function() {
+  __fillComboQuarter: function () {
     var me = this;
 
     var oStore = me.cmbQuarter.getStore();
@@ -754,12 +754,12 @@ Ext.define("Ext.dirac.utils.PlotView", {
 
     var oNewStore = new Ext.data.ArrayStore({
       fields: ["value", "text"],
-      data: oRecords
+      data: oRecords,
     });
 
     me.cmbQuarter.bindStore(oNewStore);
   },
-  __resetSelectionWindow: function() {
+  __resetSelectionWindow: function () {
     var me = this;
 
     me.cmbGroupBy.setValue(null);
@@ -777,7 +777,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
     me.fsetSpecialConditions.removeAll();
     me.cmbDomain.setValue(null);
   },
-  applyDataToSelection: function(oData, sValue, reportType) {
+  applyDataToSelection: function (oData, sValue, reportType) {
     var me = this;
 
     me.cmbReportType.setValue(reportType);
@@ -787,7 +787,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
 
     var oStore = new Ext.data.ArrayStore({
       fields: ["value", "text"],
-      data: oList
+      data: oList,
     });
 
     me.cmbPlotGenerate.setValue(null);
@@ -813,7 +813,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
           "AccountingMonitor",
           "UserManager",
           "Operator",
-          "ProductionManagement"
+          "ProductionManagement",
         ];
         var found = false;
         for (var j = 0; j < allowedProperties.length; j++) {
@@ -844,11 +844,11 @@ Ext.define("Ext.dirac.utils.PlotView", {
         anchor: "100%",
         store: new Ext.data.ArrayStore({
           fields: ["value", "text"],
-          data: oList
+          data: oList,
         }),
         labelAlign: "top",
         name: oSelectionOptions[i][0],
-        queryMode: "local"
+        queryMode: "local",
       });
 
       me.fsetSpecialConditions.add(oMultiList);
@@ -867,7 +867,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
 
     var oStore = new Ext.data.ArrayStore({
       fields: ["value", "text"],
-      data: oListForGroup
+      data: oListForGroup,
     });
 
     me.cmbGroupBy.setValue(null);
@@ -883,7 +883,7 @@ Ext.define("Ext.dirac.utils.PlotView", {
       me.advancedPlotTitle.setValue("");
     }
   },
-  applySpecialConditions: function(oData) {
+  applySpecialConditions: function (oData) {
     var me = this;
 
     var oSelectionData = oData["result"]["selectionValues"];
@@ -897,10 +897,10 @@ Ext.define("Ext.dirac.utils.PlotView", {
       oBox.loadData(oList);
     }
   },
-  __oprDoubleElementItemList: function(oList) {
+  __oprDoubleElementItemList: function (oList) {
     for (var i = 0; i < oList.length; i++) oList[i] = [oList[i], oList[i]];
   },
-  __validateConditions: function(bWithMessages) {
+  __validateConditions: function (bWithMessages) {
     var me = this;
     var bValid = true;
 
@@ -948,12 +948,12 @@ Ext.define("Ext.dirac.utils.PlotView", {
 
     return bValid;
   },
-  applyReportType: function(reportType) {
+  applyReportType: function (reportType) {
     var me = this;
 
     var categoryStore = new Ext.data.ArrayStore({
       fields: ["value", "text"],
-      data: me.reports[reportType]
+      data: me.reports[reportType],
     });
     //me.cmbDomain.setValue(null);
     me.cmbDomain.bindStore(categoryStore);
@@ -963,8 +963,8 @@ Ext.define("Ext.dirac.utils.PlotView", {
 
     var timeSelector = new Ext.data.ArrayStore({
       fields: ["value", "text"],
-      data: me.dataSelectors[me.actualReport]["dataSelector"]
+      data: me.dataSelectors[me.actualReport]["dataSelector"],
     });
     me.cmbTimeSpan.bindStore(timeSelector);
-  }
+  },
 });
